@@ -1,10 +1,12 @@
-use autodie;
+package Time::Tzfile;
+$Time::Tzfile::VERSION = '0.03';
 use strict;
 use warnings;
-package Time::Tzfile;
-$Time::Tzfile::VERSION = '0.02';
+
+use autodie ':all';
 use Config;
-#ABSTRACT: reads a binary tzfile into a hashref
+
+#ABSTRACT: read binary tzfiles into Perl data structures
 
 
 sub parse {
@@ -92,7 +94,7 @@ sub parse_bytes (*$@) {
 
 sub parse_header {
   my ($fh) = @_;
-  my $header = parse_bytes($fh, 44, 'a4 A x15 N N N N N N');
+  my $header = parse_bytes($fh, 44, 'a4 a x15 N N N N N N');
 
   die 'This file does not appear to be a tzfile'
     if $header->[0] ne 'TZif';
@@ -212,11 +214,11 @@ __END__
 
 =head1 NAME
 
-Time::Tzfile - reads a binary tzfile into a hashref
+Time::Tzfile - read binary tzfiles into Perl data structures
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
